# coding: utf-8

"""
Code generated by OpenAPI Generator (https://openapi-generator.tech), manual changes will be lost - read more on https://github.com/algolia/api-clients-automation. DO NOT EDIT.
"""
from __future__ import annotations

from enum import Enum
from json import loads
from typing import Self


class LookingSimilarModel(str, Enum):
    """
    Looking similar model.  This model recommends items that look similar to the item with the ID `objectID` based on image attributes in your index.
    """

    """
    allowed enum values
    """
    LOOKING_MINUS_SIMILAR = "looking-similar"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LookingSimilarModel from a JSON string"""
        return cls(loads(json_str))
