# coding: utf-8

"""
Code generated by OpenAPI Generator (https://openapi-generator.tech), manual changes will be lost - read more on https://github.com/algolia/api-clients-automation. DO NOT EDIT.
"""
from __future__ import annotations

from enum import Enum
from json import loads
from typing import Self


class RunReasonCode(str, Enum):
    """
    A code for the task run's outcome. A readable description of the code is included in the `reason` response property.
    """

    """
    allowed enum values
    """
    INTERNAL = "internal"
    CRITICAL = "critical"
    NO_EVENTS = "no_events"
    TOO_MANY_ERRORS = "too_many_errors"
    OK = "ok"
    DISCARDED = "discarded"
    BLOCKING = "blocking"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RunReasonCode from a JSON string"""
        return cls(loads(json_str))
